yakumo.neutron.v2.security_group_rule

Package yakumo :: Package neutron :: Package v2 :: Module security_group_rule |
[hide private]
[frames] | no frames]

# Module security_group_rule

source code

Resource class and its manager for security group rules in Networking V2 API

Classes | [hide private]
| Resource Resource class for security group rules in Networking V2 API
| Manager Manager class for security group rules in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('direction', 'direction', mapper.Noop), (
      'ethertype', 'ethertype', mapper.Noop), ('remote_ip_prefix', 'remote_i
      p_prefix', mapper.Noop), ('port_range_max', 'port_range_max', mapper.N
      oop), ('port_range_min', 'port_range_min', mapper.Noop), ('protocol',
      'protocol', mapper.Noop), ('security_group', 'security_group_id', mapp
      er.Resource('neutron.security_group')), ('remote_group', 'remote_group
      _id', mapper.Resource('neutron.security_group')), ('project', 'tenant_
      id', mapper.Resource('project')),]